function [xcoord,ycoord,zcoord,t]  = ixf_showxyz(varargin)
%-----help for libisis graphics ixf_showxyz show xyz function--------------
%Function Syntax: 
%
% >> [xcoord,ycoord,zcoord] = ixf_showxyz('property','value'...)
% or
% >> [xcoord, ycoord, zcoord] = ixf_showxyz('text','property','value',...)
%
%Purpose: Display x, y, z coordinates of plot
%
%Output: x coordinates, y coordinates and z coordinates.
%
%Inputs: inputs should be property, value pairs, available options are:
% 
%           'no_points'         value will be the number of points which you
%                               want to get from the plot (default is until
%                               keypress - same as empty)
%
%           'display_coords'    value will be true to add the co-ordinates
%                               to the end of any text, false not to (default) 
%
%           'text'              value will be a string to add to the plot
%                               at the selected point
%
%           'closest point'     Instead of the nearest intersecting
%                               surface, the closest actual data point will
%                               be found.
%
%           if a string 'text' is given as the first argument, it is
%           assumed that this is text to add to the selected point. 
%Example:
%
% >>  [x, y, z] = ixf_showxy('text','display_coords',1)
%
%--------------------------------------------------------------------------
[IXG_ST_ERROR, IXG_ST_STDVALUES] = ixf_global_var('libisis_graphics','get','IXG_ST_ERROR','IXG_ST_STDVALUES');

t = '';
xcoord = [];
ycoord = [];
zcoord = [];


% parse varargin 
arglist = struct('no_points',[],'display_coords',false,'text','','closest_point',0);

[parse, args, present] = parse_arguments(varargin, arglist);

% assume any text at the start is text to place on the plot

if ~isempty(parse) && isempty(args.text)
    if length(parse) == 1
        args.text = parse{1};
    else
        warning('unrecognised property-value pairs passed');
    end
end

%---- error checks

if ~ ischar(args.text)
    error('incorrect format for property "text",  requires a single character string')
end

if ~ isnumeric(args.no_points)
    error('incorrect format for property "no_points", requires a numerical value')
end

if ~ islogical(args.display_coords)
    error('incorrect format for property "display_coords", requires a logical value (TRUE or FALSE)')
end

%-----------check figure
flag = ixf_checkinit('Currentfigure');
if (flag == IXG_ST_STDVALUES.false)
    ixf_display_error(IXG_ST_ERROR.no_figure);
end

if ~ ixf_check_graphicfigure('handle',gcf)
    ixf_display_error(IXG_ST_ERROR.no_figure);
end

[figureHandle_, axesHandle_, plotHandle_, otherHandle_] = ixf_get_related_handles(gcf);

%---get handles and data
plot_types = zeros(size(plotHandle_));
for i = 1:length(plotHandle_)
    plot_types(i) = ixf_plotdata('get',plotHandle_(i),'plot_type');
end

%--- check for optional argument
button = 1;
i = 1;
while button == 1 
    [x,y,button] = ginput(1);
    if button == 1
    warning off
        [point, vertex, vi, face, facei] = ixf_select3d();
        objectHandle_ = gco;
    warning on
    
    % if a multiplot, replace the point with vertex inforation, so closest
    % point rather than closest surface.
    
    if all(plot_types == IXG_ST_STDVALUES.waterfall_type) || args.closest_point || all(plot_types == IXG_ST_STDVALUES.twod_line_type)
        point = vertex;
    end

    % get the co-ordinates 
    %=== if one-d type, can use just the x and y co-ordinates given by
    %ginput.
    if all(plot_types == IXG_ST_STDVALUES.oned_type)
        if args.closest_point
              [xcoord(i), ycoord(i)] = find_closest(x, y, plotHandle_);
              zcoord(i) = 0;
        else
            xcoord(i) = x;       ycoord(i) = y;       zcoord(i) = 0;
        end
    elseif isempty(point) 
                                    % if 1d type then point{i} will
                                    % be empty but we don't want to do
                                    % this 
        xcoord(i) = NaN;    ycoord(i) = NaN;   zcoord(i) = NaN;
        warning('No surface intersects selected point.')
    else
%=== if area, need to get z point such that it coresponds to the z value at
%    the nearest point rounding DOWN (i.e. coresponds to the value of the
%    colour in the box clicked in)
        if all(plot_types == IXG_ST_STDVALUES.area_type)
            point = find_area_zdata(point, plotHandle_);
        end
        
        object_type = ixf_plotdata('get',objectHandle_,'type');
        
        if all(object_type == IXG_ST_STDVALUES.patch_type)
            xyzdata = ixf_plotdata('get',objectHandle_,'xyzdata');
            point(3) = xyzdata.z(facei);
        end
        xcoord(i) = point(1);   ycoord(i) = point(2);   zcoord(i) = point(3);
    end
        
    % get the text 
        if args.display_coords
            if ~all(plot_types == IXG_ST_STDVALUES.oned_type)
                text = [args.text, ' (' num2str(truncdig(xcoord(i),3)) ', ' num2str(truncdig(ycoord(i),3)) ', ' num2str(truncdig(zcoord(i),3)) ')'];
            else
                text = [args.text, ' (' num2str(truncdig(xcoord(i),3)) ', ' num2str(truncdig(ycoord(i),3)) ')'];
            end
        else
            text = args.text;
        
        end
        
% display any text
        if ~isempty(text) && ~(all(isnan([xcoord(i), ycoord(i), zcoord(i)])) || isempty([xcoord(i), ycoord(i), zcoord(i)]))
            t = ixf_place_text(xcoord(i),ycoord(i),zcoord(i),text);
        end

% use no_points if it's given.
        if ~ isempty(args.no_points)
            args.no_points = args.no_points -1;
                if args.no_points < 1
                    button = 0;
                end
        end
        i = i + 1;
    end
end


function point = find_area_zdata(point, plotHandle_)
% function to add the z data to a point which just has x and y co-ordinates 
% on an area plot only. 
    % construct an array [plot_index, x_index, y_index, x^2+y^2]

if isempty(point)
    point = [];
    return
end

    index_array = [];

xdata = get(plotHandle_,'xdata');

if isnumeric(xdata)
    xdata = {xdata};
end

ydata = get(plotHandle_,'ydata');

if isnumeric(ydata)
    ydata = {ydata};
end

    for i = 1:length(xdata)

        point_index = xdata{i} < point(1) & ydata{i} < point(2);
        found_point = max(find(point_index));

        if ~ (isempty(found_point))
            found_data = (point(1)-xdata{i}(found_point)).^2 + (point(2) - ydata{i}(found_point)).^2;
            index_array = [index_array; i, found_point, found_data];
        end
    end

    % sort the array so that minimise the distance between points.

    if ~ isempty(index_array)
        index_array = sortrows(index_array,3);

        point_index = index_array(1,2);
        zdata = get(plotHandle_(index_array(1,1)),'cdata');

        point(3) = zdata(point_index);

        index_array = [];
    end


function [xout, yout] = find_closest(xin, yin, plotHandle_)
% find the closest point in x and y, only works for single x,y 
% input: point - single numeric vector
if isempty(xin) || isempty(yin);
    xout = [];  yout = [];
    return
end

xdata = get(plotHandle_,'xdata');

if isnumeric(xdata)
    xdata = {xdata};
end

ydata = get(plotHandle_,'ydata');

if isnumeric(ydata)
    ydata = {ydata};
end

% we minimise the distance between points using pythagoras
min_distances = ones(size(plotHandle_));
min_index = ones(size(plotHandle_));
for i = 1:length(plotHandle_)
    distance = (abs(xdata{i} - xin)).^2 + (abs(ydata{i} - yin)).^2;
    min_distances(i) = min(distance);
    min_index(i) = min(find(min_distances(i) == distance));
end

% there may be many plots, so we have to look at each separately, then take
% the minimum distance again from what we found individually.
plot_index = min(min_distances) == min_distances;
array_index = min_index(plot_index);

% now we have the minimum point from all plots
xout = xdata{plot_index}(array_index);
yout= ydata{plot_index}(array_index);

    
